#include <iostream>
#include <string>
#include <vector>
#include <algorithm>
#include <math.h>
#include <climits>
#include <map>

using namespace std;

#define ull unsigned long long
#define ll long long

const int N = 1073741824;
// const int N = 128;
const double eps = 0.00000001;

struct segtree {
    int l, r, u, d;
    bool clean = false;
    int value = 0;
    segtree *upl = 0, *upr = 0, *dl = 0, *dr = 0;
    
    segtree(int l, int r, int u, int d) : l(l), r(r), u(u), d(d) {
        // build();
    }

    void build() {
        if (upl) return;

        if (l + 1 >= r && d + 1 >= u) {
            // do nothing
        }
        else if (l + 1 < r && d + 1 < u) {
            upl = new segtree(l, (r+l)/2, u, (u+d)/2);
            upr = new segtree((r+l)/2, r, u, (u+d)/2);
            dl = new segtree(l, (r+l)/2, (u+d)/2, d);
            dr = new segtree((r+l)/2, r, (u+d)/2, d);
        }
        else if (l + 1 < r) {
            upl = new segtree(l, (r+l)/2, u, (u+d)/2);
            upr = new segtree((r+l)/2, r, u, (u+d)/2);
        }
        else if (d + 1 < u) {
            upl = new segtree(l, (r+l)/2, u, (u+d)/2);
            dl = new segtree(l, (r+l)/2, (u+d)/2, d);
        }
    }

    bool fully_in(int lq, int rq, int uq, int dq) {
        return ((lq <= l && r <= rq) && (dq <= d && u <= uq));
    }

    bool partially_in(int lq, int rq, int uq, int dq) {
        return partially_in_x(lq, rq) && partially_in_y(uq, dq);
    }

    bool partially_in_x(int lq, int rq) {
        return !(r <= lq || l >= rq);
    }

    bool partially_in_y(int uq, int dq) {
        return !(d >= uq || u <= dq);
    }

    bool not_in(int lq, int rq, int uq, int dq) {
        return !partially_in(lq, rq, uq, dq);
    }

    void push() {
        if (clean) {
            if (upl)
                upl->set(l,r,u,d);
            if (upr)
                upr->set(l,r,u,d);
            if (dl)
                dl->set(l,r,u,d);
            if (dr)
                dr->set(l,r,u,d);

            clean = false;
        }
    }

    void set(int lq, int rq, int uq, int dq) {
        build();
        if (not_in(lq, rq, uq, dq)) {
            return;
        }
        else if (fully_in(lq, rq, uq, dq)) {
            clean = true;
            value = abs(r-l) * abs(u-d);

            // get(l, r, u, d);
        }
        else { // partially in
            value = 0;

            if (upl) { upl->set(lq, rq, uq, dq); value += upl->value; }
            if (upr) { upr->set(lq, rq, uq, dq); value += upr->value; }
            if (dl) { dl->set(lq, rq, uq, dq); value += dl->value; }
            if (dr) { dr->set(lq, rq, uq, dq); value += dr->value; }

            get(l, r, u, d);
        }
    }

    int get(int lq, int rq, int uq, int dq) {
        build();
        push();
        if (fully_in(lq, rq, uq, dq)) {
            // cout << "get fully in" << endl;
            return value;
        }
        else if (not_in(lq, rq, uq, dq)) {
            // cout <<l<<r<<u<<d << " not in " << lq << rq << uq << dq << endl;
            return 0;
        }
        else {
            int ans = 0;
            if (upl) ans += upl->get(lq, rq, uq, dq);
            if (upr) ans += upr->get(lq, rq, uq, dq);
            if (dl) ans += dl->get(lq, rq, uq, dq);
            if(dr) ans += dr->get(lq, rq, uq, dq);
            
            return ans;
        }
    }
};


int main() {
    int n, k;
    cin >> k >> n;
    segtree s(-N, N, N, -N);
    // segtree *seg = &s;
    // while(seg) {
    //     cout << seg-> l << " " << seg->r << " " << seg->u << " " << seg->d << "  -> " << seg->get(seg->l, seg->r, seg->u, seg->d) << endl;
    //     seg = seg->upl;
    // }

    int x = 0, y = 0;

    s.set(x, x+k, y+k, y);
    while(n--) {
        string cmd;
        int ai;
        cin >> cmd >> ai;

        if(cmd=="W") { // left
            s.set(x-ai, x+k, y+k, y);
            // cout << s.get(x-ai, x+k, y+k, y) << endl;
            x -= ai;
        }
        else if(cmd=="E") { // right
            s.set(x, x+ai+k, y+k, y);
            // cout << s.get(x, x+ai+k, y+k, y) << endl;
            x += ai;
        }
        else if(cmd=="N") { // up

            s.set(x, x+k, y+ai+k, y);
            // cout << s.get(x, x+k, y+ai+k, y) << endl;
            y += ai;
        }
        else if(cmd=="S") { // down
            s.set(x, x+k, y+k, y-ai);
            // cout << s.get(x, x+k, y+k, y-ai) << endl;
            y -= ai;
        }
    }

    cout << s.get(-N, N, N, -N) << endl;
}


/*
1 5
E 2
N 2
W 4
S 4
E 4

3 4
W 2
N 1
W 1
N 2
*/